# aiohttp-fast-url-dispatcher

**Documentation**: <a href="https://aiohttp-fast-url-dispatcher.readthedocs.io" target="_blank">https://aiohttp-fast-url-dispatcher.readthedocs.io </a>

**Source Code**: <a href="https://github.com/bdraco/aiohttp-fast-url-dispatcher" target="_blank">https://github.com/bdraco/aiohttp-fast-url-dispatcher </a>

---

A faster URL dispatcher for aiohttp

The default `UrlDispatcher` implementation does a linear search every which can have a significant [TimeComplexity](https://wiki.python.org/moin/TimeComplexity) when dispatching urls when there are a lot of routes. `FastUrlDispatcher` keeps an index of the urls which allows for fast dispatch.

This library will become obsolete with aiohttp 3.10 as the changes
are expected to merge upstream via https://github.com/aio-libs/aiohttp/pull/7829

## Installation

Install this via pip (or your favourite package manager):

`pip install aiohttp-fast-url-dispatcher`

## Usage

Attach to a `web.Application` before any resources are registered.

```python
dispatcher = FastUrlDispatcher()
app = web.Application()
attach_fast_url_dispatcher(app, dispatcher)
```

Create with a new `web.Application`

```python
dispatcher = FastUrlDispatcher()
app = web.Application(router=dispatcher)
```

### Caveats

If you have multiple handlers that resolve to the same URL, this module will always prefer the static name over a dynamic name. For example:

```python
app.router.add_get(r"/second/{user}/info", handler)
app.router.add_get("/second/bob/info", handler)
```

`"/second/bob/info"` will always be matched before `r"/second/{user}/info"`

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- prettier-ignore-start -->
<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- markdownlint-disable -->
<!-- markdownlint-enable -->
<!-- ALL-CONTRIBUTORS-LIST:END -->
<!-- prettier-ignore-end -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!

## Credits

This package was created with
[Copier](https://copier.readthedocs.io/) and the
[browniebroke/pypackage-template](https://github.com/browniebroke/pypackage-template)
project template.
